@@ -34,11 +34,10 @@ defined('_JEXEC') or die('Restricted access');
 <div id="report-response">
 	<div>
 		<p><?php echo JText::_('COM_SUPPORT_ERROR_PROCESSING_FORM'); ?></p>
-		<p><a href="javascript:HUB.Modules.ReportProblems.reshowForm();" title="<?php echo JText::_('COM_SUPPORT_EDIT_REPORT'); ?>"><?php echo JText::_('COM_SUPPORT_EDIT_REPORT'); ?></a></p>
+		<p><a href="javascript:HUB.ReportProblem.reshowForm();" title="<?php echo JText::_('COM_SUPPORT_EDIT_REPORT'); ?>"><?php echo JText::_('COM_SUPPORT_EDIT_REPORT'); ?></a></p>
 	</div>
 	<h3><?php echo JText::_('COM_SUPPORT_ERROR'); ?></h3>
 	<p><?php echo JText::_('COM_SUPPORT_ERROR_PROCESSING_DESCRIPTION'); ?></p>
 <?php if ($this->getError()) { echo '<p>' . $this->getError() . '</p>'; } ?>
 </div>
-
-<script type="text/javascript">window.top.window.HUB.Modules.ReportProblems.hideTimer();</script>
\ No newline at end of file
+<script type="text/javascript">window.top.window.HUB.ReportProblem.hideTimer();</script>
\ No newline at end of file
