@@ -89,11 +89,11 @@ class WikiControllerPage extends Hubzero_Controller
 		define('WIKI_MAX_PAGENAME_LENGTH', $this->config->get('max_pagename_length', 100));
 
 		$wp = new WikiPage($this->database);
-		if (!$wp->count()) 
+		if (!$wp->count($this->_group)) 
 		{
 			include_once(JPATH_ROOT . DS . 'components' . DS . 'com_wiki' . DS . 'helpers' . DS . 'setup.php');
 
-			$result = WikiSetup::initialize($this->_option);
+			$result = WikiSetup::initialize($this->_option, $this->_group);
 			if ($result) 
 			{
 				$this->setError($result);
@@ -325,6 +325,21 @@ class WikiControllerPage extends Hubzero_Controller
 			$this->view->tags = $this->page->getTags();
 		}*/
 
+		// Handle display events
+		JPluginHelper::importPlugin('wiki');
+		$dispatcher =& JDispatcher::getInstance();
+
+		$this->page->event = new stdClass();
+
+		$results = $dispatcher->trigger('onAfterDisplayTitle', array($this->page, &$this->view->revision, $this->config));
+		$this->page->event->afterDisplayTitle = trim(implode("\n", $results));
+
+		$results = $dispatcher->trigger('onBeforeDisplayContent', array(&$this->page, &$this->view->revision, $this->config));
+		$this->page->event->beforeDisplayContent = trim(implode("\n", $results));
+
+		$results = $dispatcher->trigger('onAfterDisplayContent', array(&$this->page, &$this->view->revision, $this->config));
+		$this->page->event->afterDisplayContent = trim(implode("\n", $results));
+
 		$this->view->message = $this->_message;
 
 		if ($this->getError()) 
@@ -687,7 +702,7 @@ class WikiControllerPage extends Hubzero_Controller
 		$page = JRequest::getVar('page', array(), 'post', 'none', 2);
 
 		$this->page = new WikiPage($this->database);
-		$this->page->load($rev['pageid']);
+		$this->page->loadById($rev['pageid']);
 		$this->page->title    = (isset($page['title']))  ? trim($page['title'])    : '';
 		$this->page->pagename = trim(JRequest::getVar('pagename', '', 'post'));
 		$this->page->scope    = trim(JRequest::getVar('scope', '', 'post'));
@@ -741,6 +756,15 @@ class WikiControllerPage extends Hubzero_Controller
 		}
 
 		// Check content
+		// First, make sure the pagetext isn't empty
+		if (empty($this->revision->pagetext)) 
+		{
+			$this->setError(JText::_('Page text is required'));
+			$this->editTask();
+			return;
+		}
+
+		// Then make sure all checks pass concerning the page
 		if (!$this->page->check()) 
 		{
 			$this->setError($this->page->getError());
@@ -852,6 +876,15 @@ class WikiControllerPage extends Hubzero_Controller
 			}
 		}
 
+		$this->page->version_id = $this->revision->id;
+		$this->page->modified   = $this->revision->created;
+		if (!$this->page->store()) 
+		{
+			// This really shouldn't happen.
+			JError::raiseWarning(500, $this->page->getError());
+			return;
+		}
+
 		// Process tags
 		$tags = trim(JRequest::getVar('tags', ''));
 		$tagging = new WikiTags($this->database);
