@@ -262,22 +262,54 @@ class Hubzero_Group
 	}
 
 	/**
-	 * Short description for 'getInstance'
-	 * Long description (if any) ...
+	 * Returns a reference to a group object
 	 *
-	 * @param unknown $group Parameter description (if any) ...
-	 * @return mixed Return description (if any) ...
+	 * @param     mixed $group A string (cn) or integer (ID)
+	 * @return    mixed Object if instance found, false if not
 	 */
 	static public function getInstance($group)
 	{
-		$hzg = new Hubzero_Group();
+		static $instances;
 
-		if ($hzg->read($group) === false)
+		// Set instances array
+		if (!isset($instances)) 
 		{
-			return false;
+			$instances = array();
 		}
 
-		return $hzg;
+		// Do we have a matching instance?
+		if (!isset($instances[$group])) 
+		{
+			// If an ID is passed, check for a match in existing instances
+			if (is_numeric($group))
+			{
+				foreach ($instances as $instance)
+				{
+					if ($instance && $instance->get('gidNumber') == $group)
+					{
+						// Match found
+						return $instance;
+						break;
+					}
+				}
+			}
+
+			// No matches
+			// Create group object
+			$hzg = new Hubzero_Group();
+
+			if ($hzg->read($group) === false)
+			{
+				$instances[$group] = false;
+			}
+			else
+			{
+				$instances[$group] = $hzg;
+			}
+		}
+
+		// Return instance
+		return $instances[$group];
 	}
 
 	/**
@@ -1431,15 +1463,22 @@ class Hubzero_Group
 		{
 			return false;
 		}
+		
+		if($q == '')
+		{
+			return false;
+		}
 
 		$table = '#__xgroups_' . $tbl;
+		$user_table = '#__users';
 
 		$db = & JFactory::getDBO();
 
-		$query = 'SELECT u.id FROM #__xgroups_ ' . $tbl . ' AS t,#__users AS u WHERE t.gidNumber=' . $db->Quote($this->gidNumber) . " AND u.id=t.uidNumber AND LOWER(u.name) LIKE '%" . strtolower($q) . "%';";
-
+		$query = "SELECT u.id FROM {$table} AS t, {$user_table} AS u 
+					WHERE t.gidNumber={$db->Quote($this->gidNumber)} 
+					AND u.id=t.uidNumber 
+					AND LOWER(u.name) LIKE '%" . strtolower($q) . "%';";
 		$db->setQuery($query);
-
 		return $db->loadResultArray();
 	}
 }
\ No newline at end of file
