@@ -30,28 +30,33 @@
 
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
+
+$mode = $this->page->params->get('mode', 'wiki');
 ?>
-<header id="<?php echo ($this->sub) ? 'sub-content-header' : 'content-header'; ?>" class="full">
+<div id="<?php echo ($this->sub) ? 'sub-content-header' : 'content-header'; ?>" class="full">
 	<h2><?php echo $this->escape($this->title); ?></h2>
 	<?php
-	if (!$this->page->isStatic())
-	{
+	if (!$mode || ($mode && $mode != 'static')) {
 		$view = new JView(array(
-			'base_path' => $this->base_path,
+			'base_path' => $this->base_path, 
 			'name'      => 'page',
 			'layout'    => 'authors'
 		));
+		$view->option = $this->option;
 		$view->page   = $this->page;
+		$view->task   = $this->task;
+		$view->config = $this->config;
+		//$view->revision = $this->revision;
 		$view->display();
 	}
 	?>
-</header><!-- /#content-header -->
+</div><!-- /#content-header -->
 
 <?php
-if ($this->page->exists())
+if ($this->page->id) 
 {
 	$view = new JView(array(
-		'base_path' => $this->base_path,
+		'base_path' => $this->base_path, 
 		'name'      => 'page',
 		'layout'    => 'submenu'
 	));
@@ -64,6 +69,7 @@ if ($this->page->exists())
 }
 ?>
 
-<section class="main section">
-	<p class="warning"><?php echo JText::sprintf('A page could not be found matching the version number "%s".', $this->version); ?></p>
-</section><!-- / .main section -->
+<div class="main section">
+	<p class="warning">A page could not be found matching the version number <?php echo $this->version; ?>.</p>
+	<div class="clear"></div>
+</div><!-- / .main section -->
