@@ -31,10 +31,12 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+jimport('joomla.plugin.plugin');
+
 /**
  * Support plugin class for CAPTCHA
  */
-class plgSupportCaptcha extends \Hubzero\Plugin\Plugin
+class plgSupportCaptcha extends JPlugin
 {
 	/**
 	 * If the user is a verified, logged-in user
@@ -77,117 +79,117 @@ class plgSupportCaptcha extends \Hubzero\Plugin\Plugin
 	 */
 	private $_questions = array(
 		array(
-			'type'     => 'math',
+			'type' => 'math',
 			'question' => 'PLG_SUPPORT_TEXTCAPTCHA_MATH',
-			'answer'   => '@dynamic'
+			'answer' => '@dynamic'
 		),
 		array(
-			'type'     => 'list',
-			'question' => 'PLG_SUPPORT_TEXTCAPTCHA_WHAT_DAY_AFTER_TUESDAY',
-			'options'  => array(
-				'WEDNESDAY',
-				'MONDAY',
-				'THURSDAY',
-				'TUESDAY',
-				'FRIDAY'
+			'type' => 'list',
+			'question' => 'What day comes after Tuesday?',
+			'options' => array(
+				'Wednesday',
+				'Monday',
+				'Thursday',
+				'Tuesday',
+				'Friday'
 			),
-			'answer'   => 'WEDNESDAY'
+			'answer' => 'Wednesday'
 		),
 		array(
-			'type'     => 'text',
-			'question' => 'PLG_SUPPORT_TEXTCAPTCHA_EYE_ANKLE_ARM',
-			'answer'   => 'PLG_SUPPORT_TEXTCAPTCHA_EYE_ANKLE_ARM_ANSWER'
+			'type' => 'text',
+			'question' => 'Eye, ankle or arm: which is part of the head?',
+			'answer' => 'eye'
 		),
 		array(
-			'type'     => 'list',
-			'question' => 'PLG_SUPPORT_TEXTCAPTCHA_SUN_RISES',
-			'options'  => array(
-				'PLG_SUPPORT_TEXTCAPTCHA_SUN_RISES_EAST',
-				'PLG_SUPPORT_TEXTCAPTCHA_SUN_RISES_NIGHT',
-				'PLG_SUPPORT_TEXTCAPTCHA_SUN_RISES_SOUTH',
-				'PLG_SUPPORT_TEXTCAPTCHA_SUN_RISES_WEST',
-				'PLG_SUPPORT_TEXTCAPTCHA_SUN_RISES_CHICKENS'
+			'type' => 'list',
+			'question' => 'Where does the sun rise?',
+			'options' => array(
+				'In the East',
+				'At night',
+				'In the South',
+				'In the West',
+				'Chickens'
 			),
-			'answer'   => 'PLG_SUPPORT_TEXTCAPTCHA_SUN_RISES_EAST'
+			'answer' => 'In the East'
 		),
 		array(
-			'type'     => 'list',
-			'question' => 'PLG_SUPPORT_TEXTCAPTCHA_PYRAMIDS',
-			'options'  => array(
-				'PLG_SUPPORT_TEXTCAPTCHA_PYRAMIDS_EGYPT',
-				'PLG_SUPPORT_TEXTCAPTCHA_PYRAMIDS_ROCKS',
-				'PLG_SUPPORT_TEXTCAPTCHA_PYRAMIDS_JAPAN',
-				'PLG_SUPPORT_TEXTCAPTCHA_PYRAMIDS_NORTH_POLE',
-				'PLG_SUPPORT_TEXTCAPTCHA_PYRAMIDS_CANADA'
+			'type' => 'list',
+			'question' => 'The Great Pyramid is found in...',
+			'options' => array(
+				'Egypt',
+				'Rocks',
+				'Japan',
+				'The North Pole',
+				'Canada'
 			),
-			'answer'   => 'PLG_SUPPORT_TEXTCAPTCHA_PYRAMIDS_EGYPT'
+			'answer' => 'Egypt'
 		),
 		array(
-			'type'     => 'list',
-			'question' => 'PLG_SUPPORT_TEXTCAPTCHA_MOON',
-			'options'  => array(
-				'PLG_SUPPORT_TEXTCAPTCHA_MOON_SKY',
-				'PLG_SUPPORT_TEXTCAPTCHA_MOON_AUTOMOBILES',
-				'PLG_SUPPORT_TEXTCAPTCHA_MOON_CLOSET',
-				'PLG_SUPPORT_TEXTCAPTCHA_MOON_MOVIES',
-				'PLG_SUPPORT_TEXTCAPTCHA_MOON_DRAWER'
+			'type' => 'list',
+			'question' => 'The moon can be seen...',
+			'options' => array(
+				'In the sky',
+				'Under automobiles',
+				'In the closet',
+				'Going to the movies',
+				'In a desk drawer'
 			),
-			'answer'   => 'PLG_SUPPORT_TEXTCAPTCHA_MOON_SKY'
+			'answer' => 'In the sky'
 		),
 		array(
-			'type'     => 'text',
-			'question' => 'PLG_SUPPORT_TEXTCAPTCHA_ICE',
-			'answer'   => 'PLG_SUPPORT_TEXTCAPTCHA_ICE_ANSWER'
+			'type' => 'text',
+			'question' => 'Is ice hot or cold?',
+			'answer' => 'cold'
 		),
 		array(
-			'type'     => 'text',
-			'question' => 'PLG_SUPPORT_TEXTCAPTCHA_BODY_PART',
-			'answer'   => 'PLG_SUPPORT_TEXTCAPTCHA_BODY_PART_ANSWER'
+			'type' => 'text',
+			'question' => 'Which of arm, chips or prison is a body part?',
+			'answer' => 'arm'
 		),
 		array(
-			'type'     => 'list',
-			'question' => 'PLG_SUPPORT_TEXTCAPTCHA_SHARKS',
-			'options'  => array(
-				'PLG_SUPPORT_TEXTCAPTCHA_SHARKS_SEA',
-				'PLG_SUPPORT_TEXTCAPTCHA_SHARKS_APRICOTS',
-				'PLG_SUPPORT_TEXTCAPTCHA_SHARKS_GREENHOUSES',
-				'PLG_SUPPORT_TEXTCAPTCHA_SHARKS_BARRELS',
-				'PLG_SUPPORT_TEXTCAPTCHA_SHARKS_HOUSE'
+			'type' => 'list',
+			'question' => 'Sharks live in...',
+			'options' => array(
+				'The Sea',
+				'Apricots',
+				'Greenhouses',
+				'Beer barrels',
+				'House'
 			),
-			'answer'   => 'PLG_SUPPORT_TEXTCAPTCHA_SHARKS_SEA'
+			'answer' => 'The Sea'
 		),
 		array(
-			'type'     => 'text',
-			'question' => 'PLG_SUPPORT_TEXTCAPTCHA_NIGHT',
-			'answer'   => 'PLG_SUPPORT_TEXTCAPTCHA_NIGHT_ANSWER'
+			'type' => 'text',
+			'question' => 'Is night dark or light?',
+			'answer' => 'dark'
 		),
 		array(
-			'type'     => 'text',
-			'question' => 'PLG_SUPPORT_TEXTCAPTCHA_COLOR',
-			'answer'   => 'PLG_SUPPORT_TEXTCAPTCHA_COLOR_ANSWER'
+			'type' => 'text',
+			'question' => 'Which of hair, yellow or prison is a color?',
+			'answer' => 'yellow'
 		),
 		array(
-			'type'     => 'text',
-			'question' => 'PLG_SUPPORT_TEXTCAPTCHA_CAPITAL_OF_FRANCE',
-			'answer'   => 'PLG_SUPPORT_TEXTCAPTCHA_CAPITAL_OF_FRANCE_ANSWER'
+			'type' => 'text',
+			'question' => 'What is the capital of France?',
+			'answer' => 'Paris'
 		),
 		array(
-			'type'     => 'list',
-			'question' => 'PLG_SUPPORT_TEXTCAPTCHA_MICKEY',
-			'options'  => array(
-				'PLG_SUPPORT_TEXTCAPTCHA_MICKEY_MOUSE',
-				'PLG_SUPPORT_TEXTCAPTCHA_MICKEY_TEAPOT',
-				'PLG_SUPPORT_TEXTCAPTCHA_MICKEY_SUITCASE',
-				'PLG_SUPPORT_TEXTCAPTCHA_MICKEY_PENGUIN',
-				'PLG_SUPPORT_TEXTCAPTCHA_MICKEY_CHICKEN'
+			'type' => 'list',
+			'question' => 'Mickey Mouse is a...',
+			'options' => array(
+				'Mouse',
+				'Teapot',
+				'Suitcase',
+				'Penguin',
+				'Chicken'
 			),
-			'answer'   => 'PLG_SUPPORT_TEXTCAPTCHA_MICKEY_MOUSE'
+			'answer' => 'Mouse'
 		)
 	);
 
 	/**
 	 * Constructor
-	 *
+	 * 
 	 * @param      object &$subject Event observer
 	 * @param      array  $config   Optional config values
 	 * @return     void
@@ -198,12 +200,12 @@ class plgSupportCaptcha extends \Hubzero\Plugin\Plugin
 
 		$this->loadLanguage();
 
-		$juser = JFactory::getUser();
-
-		if (!$juser->get('guest'))
+		$juser =& JFactory::getUser();
+		if (!$juser->get('guest')) 
 		{
-			$profile = \Hubzero\User\Profile::getInstance($juser->get('id'));
-			if ($profile->get('emailConfirmed') == 1 || $profile->get('emailConfirmed') == 3)
+			ximport('Hubzero_User_Profile');
+			$profile = Hubzero_User_Profile::getInstance($juser->get('id'));
+			if ($profile->get('emailConfirmed') == 1) 
 			{
 				$this->_verified = true;
 			}
@@ -329,38 +331,37 @@ class plgSupportCaptcha extends \Hubzero\Plugin\Plugin
 			break;
 
 			case 'list':
-				$key = strtolower(JText::_($question['answer']));
+				$key = strtolower($question['answer']);
 				$numseq = count($this->_sequence);
 				$set = rand(0, $numseq-1);
 
 				$html .= "\t" . JText::_($question['question']) . "\n";
 				$html .= "\t" . '<select name="captcha[answer]" id="captcha-answer">' . "\n";
-				$html .= "\t\t" . '<option value="">' . JText::_('PLG_SUPPORT_TEXTCAPTCHA_SELECT_ANSWER') . '</option>' . "\n";
+				$html .= "\t\t" . '<option value="">' . JText::_('- Select an answer -') . '</option>' . "\n";
 				foreach ($this->_sequence[$set] as $row)
 				{
-					$html .= "\t\t" . '<option value="' . JText::_($question['options'][$row]) . '">' . JText::_($question['options'][$row]) . '</option>' . "\n";
+					$html .= "\t\t" . '<option value="' . $question['options'][$row] . '">' . JText::_($question['options'][$row]) . '</option>' . "\n";
 				}
 				$html .= "\t" . '</select>' . "\n";
 			break;
 
 			case 'text':
 			default:
-				$key = strtolower(JText::_($question['answer']));
+				$key = strtolower($question['answer']);
 
 				$html .= "\t" . JText::_($question['question']) . "\n";
 				$html .= "\t" . '<input type="text" name="captcha[answer]" id="captcha-answer" value="" />' . "\n";
 			break;
 		}
 
-		$html .= '</label>' . "\n";
 		$html .= "\t" . '<input type="hidden" name="captcha[krhash]" id="captcha-krhash" value="' . $this->_generateHash($key, date('j')) . '" />' . "\n";
 		//$html .= "\t" . '<input type="hidden" name="captcha[type]" id="captcha-type" value="text" />' . "\n";
+		$html .= '</label>' . "\n";
 
-		$currentSession = JFactory::getSession();
+		$currentSession =& JFactory::getSession();
 		$currentSession->set('securiy_code' . JRequest::getVar('instanceNo', $GLOBALS['totalCaptchas']), $this->_generateHash($key, date('j')));
 
-		if ($this->_verified)
-		{
+		if ($this->_verified) {
 			$html  = '<input type="hidden" name="captcha[answer]" id="captcha-answer" value="' . $key . '" />' . "\n";
 		}
 
@@ -378,8 +379,8 @@ class plgSupportCaptcha extends \Hubzero\Plugin\Plugin
 	 */
 	private function _generateHash($input, $day)
 	{
-		$jconfig = JFactory::getConfig();
-
+		$jconfig =& JFactory::getConfig();
+		
 		// Add date:
 		$input .= $jconfig->getValue('config.secret') . $day . date('ny');
 
@@ -434,19 +435,14 @@ class plgSupportCaptcha extends \Hubzero\Plugin\Plugin
 	{
 		$word = $this->_generateHash(strtolower($word), date('j'));
 
-		$currentSession = JFactory::getSession();
+		$currentSession =& JFactory::getSession();
 		$securiy_code = $currentSession->get('securiy_code' . $instanceNo);
 
-		if ($hash && $word == $hash)
-		{
+		if ($hash && $word == $hash) {
 			return true;
-		}
-		else if ($word == $securiy_code)
-		{
+		} else if ($word == $securiy_code) {
 			return true;
-		}
-		else
-		{
+		} else {
 			return false;
 		}
 	}
@@ -465,17 +461,22 @@ class plgSupportCaptcha extends \Hubzero\Plugin\Plugin
 
 		$GLOBALS['totalCaptchas']++;
 
-		$view = new \Hubzero\Plugin\View(
+		ximport('Hubzero_Document');
+		Hubzero_Document::addPluginStyleSheet('support', 'captcha');
+
+		ximport('Hubzero_Plugin_View');
+		$view = new Hubzero_Plugin_View(
 			array(
-				'folder'  => $this->_type,
-				'element' => $this->_name,
-				'name'    => 'image'
+				'folder' => 'support',
+				'element' => 'captcha',
+				'name' => 'image'
 			)
 		);
-		$view->task       = JRequest::getVar('task', '');
+
+		$view->task = JRequest::getVar('task', '');
 		$view->controller = JRequest::getVar('controller', '');
-		$view->option     = JRequest::getVar('option', '');
-		$view->total      = $GLOBALS['totalCaptchas'];
+		$view->option = JRequest::getVar('option', '');
+		$view->total = $GLOBALS['totalCaptchas'];
 
 		return $view->loadTemplate();
 	}
@@ -498,13 +499,6 @@ class plgSupportCaptcha extends \Hubzero\Plugin\Plugin
 	 */
 	private function _createImageAdv()
 	{
-		if (!isset($GLOBALS['totalCaptchas']))
-		{
-			$GLOBALS['totalCaptchas'] = -1;
-		}
-
-		$GLOBALS['totalCaptchas']++;
-
 		$alphabet = "0123456789abcdefghijklmnopqrstuvwxyz";
 		$allowed_symbols = "23456789abcdeghkmnpqsuvxyz";
 
@@ -594,8 +588,8 @@ class plgSupportCaptcha extends \Hubzero\Plugin\Plugin
 						{
 							for ($sx=$m['start']-1; $sx<$m['end']; $sx+=1)
 							{
-								$rgb = imagecolorat($font, $sx, $sy);
-								$opacity = $rgb>>24;
+				        		$rgb = imagecolorat($font, $sx, $sy);
+				        		$opacity = $rgb>>24;
 								if ($opacity < 127)
 								{
 									$left = $sx-$m['start']+$x;
@@ -606,7 +600,7 @@ class plgSupportCaptcha extends \Hubzero\Plugin\Plugin
 									}
 									for ($px=min($left,$width-1); $px>$left-12 && $px>=0; $px-=1)
 									{
-										$color = imagecolorat($img, $px, $py) & 0xff;
+						        		$color = imagecolorat($img, $px, $py) & 0xff;
 										if ($color+$opacity < 190){
 											if ($shift > $left-$px)
 											{
@@ -741,8 +735,8 @@ class plgSupportCaptcha extends \Hubzero\Plugin\Plugin
 		$security_code = $this->_generateHash($this->keystring, date('j'));
 
 		//Set the session to store the security code
-		$currentSession = JFactory::getSession();
-		$currentSession->set('securiy_code' . JRequest::getVar('instanceNo', $GLOBALS['totalCaptchas']), $security_code);
+		$currentSession =& JFactory::getSession();
+		$currentSession->set('securiy_code' . (JRequest::getVar('instanceNo', $GLOBALS['totalCaptchas']) + 0), $security_code);
 		$width = 120;
 		$height = 40;
 	}
@@ -757,17 +751,17 @@ class plgSupportCaptcha extends \Hubzero\Plugin\Plugin
 		// Let's generate a totally random string using md5
 		$md5_hash = md5(rand(0,999));
 
-		// We don't need a 32 character long string so we trim it down to 5
+		// We don't need a 32 character long string so we trim it down to 5 
 		$security_code = str_replace(array("0", "O", "o"), array("p"), substr($md5_hash, 15, 5));
 		$security_code = $this->_generateHash($security_code, date('j'));
 
 		// Set the session to store the security code
-		$currentSession = JFactory::getSession();
+		$currentSession =& JFactory::getSession();
 		$currentSession->set('securiy_code' . (JRequest::getVar('instanceNo') + 0), $security_code);
 
-		$width  = 120;
+		$width = 120;
 		$height = 40;
-		$image  = imagecreate($width, $height);
+		$image = imagecreate($width, $height);
 		$this->_setColors();
 		$foreground_color = $this->_hexToRgb($this->_textColor);
 		$background_color = $this->_hexToRgb($this->_bgColor);
@@ -775,9 +769,9 @@ class plgSupportCaptcha extends \Hubzero\Plugin\Plugin
 		// We are making three colors, white, black and gray
 		$white = imagecolorallocate($image, $foreground_color[0], $foreground_color[1], $foreground_color[2]);
 		$black = imagecolorallocate($image, $background_color[0], $background_color[1], $background_color[2]);
-		$grey  = imagecolorallocate($image, 204, 204, 204);
+		$grey = imagecolorallocate($image, 204, 204, 204);
 
-		// Make the background black
+		// Make the background black 
 		imagefill($image, 0, 0, $black);
 
 		$size = 10;
